Crate deno_dotenv

Crate deno_dotenv 

Structs

FindPathAndContentError
ParseError

Functions

candidate_paths
Returns an iterator of candidate paths for the given env file specifier.
find_path_and_content
Discovers the path and content of an env file, which can then be parsed.
from_content_sanitized_iter_with_substitution
parse_env_content_hook
Ported from: https://github.com/nodejs/node/blob/9cc7fcc26dece769d9ffa06c453f0171311b01f8/src/node_dotenv.cc#L138-L315
parse_env_content_with_substitution_hook