Structs
Functions
- candidate_
paths - Returns an iterator of candidate paths for the given env file specifier.
- find_
path_ and_ content - Discovers the path and content of an env file, which can then be parsed.
- from_
content_ sanitized_ iter_ with_ substitution - parse_
env_ content_ hook - Ported from: https://github.com/nodejs/node/blob/9cc7fcc26dece769d9ffa06c453f0171311b01f8/src/node_dotenv.cc#L138-L315
- parse_
env_ content_ with_ substitution_ hook